==> wow_views-0.0.30.tar.gz: lib/components/view/vi_tri_component.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wow_views/screens/google_map/google_map.dart';
import 'package:wow_views/screens/google_map/setup_marker.dart';
import 'package:wowit/common.dart';
import 'package:wowit/message.dart';
import 'package:wowit/methods.dart';

class ViTriCompoment {
  Widget getMainView(Map<String, dynamic> data, String tableName) {
    var dataReponse = Methods.getList(data['data'], tableName);
    if (dataReponse.isNotEmpty) {
      var value = dataReponse[0];
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            Message.getMessage('BOLOC_VI_TRI'),
            style: TextStyle(
              color: Common.colorAppbar,
              fontWeight: FontWeight.bold,
              fontSize: 18,
            ),
          ),
          const SizedBox(
            height: 16,
          ),
          SizedBox(
            height: Get.height / 4,
            width: Get.width,
            child: MapLocation(
              [
                SetUpMarker(
                    value,
                    Methods.getInt(value, 'ID'),
                    Methods.getString(value, 'title'),
                    Methods.getDouble(value, 'lat'),
                    Methods.getDouble(value, 'long'),
                    backGroundColor: Common.colorAppbar,
                    textColor: Colors.white)
              ],
            ),
          ),
        ],
      );
    }
    return Container();
  }
}

==> wow_views-0.0.38.tar.gz: lib/components/view/vi_tri_component.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wow_views/screens/google_map/google_map.dart';
import 'package:wow_views/screens/google_map/setup_marker.dart';
import 'package:wowit/common.dart';
import 'package:wowit/message.dart';
import 'package:wowit/methods.dart';

class ViTriCompoment {
  Widget getMainView(Map<String, dynamic> data, String tableName) {
    var dataReponse = Methods.getList(data['data'], tableName);
    if (dataReponse.isNotEmpty) {
      var value = dataReponse[0];
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            Message.getMessage('BOLOC_VI_TRI'),
            style: TextStyle(
              color: Common.colorAppbar,
              fontWeight: FontWeight.bold,
              fontSize: 18,
            ),
          ),
          const SizedBox(
            height: 16,
          ),
          SizedBox(
            height: Get.height / 4,
            width: Get.width,
            child: MapLocation(
              [
                SetUpMarker(
                  value,
                  id: Methods.getInt(value, 'ID'),
                  title: Methods.getString(value, 'title'),
                  latitude: Methods.getDouble(value, 'lat'),
                  longitude: Methods.getDouble(value, 'long'),
                  backGroundColor: Common.colorAppbar,
                  textColor: Colors.white,
                )
              ],
            ),
          ),
        ],
      );
    }
    return Container();
  }
}
